Mixed-Up Code Exercises
-----------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: mucp_13_1_sq
   :fromid: mucp_13_1, mucp_13_1_ac_q
   :toggle:

.. selectquestion:: mucp_13_2_sq
   :fromid: mucp_13_2, mucp_13_2_ac_q
   :toggle:

.. selectquestion:: mucp_13_3_sq
   :fromid: mucp_13_3, mucp_13_3_ac_q
   :toggle:

.. selectquestion:: mucp_13_4_sq
   :fromid: mucp_13_4, mucp_13_4_ac_q
   :toggle:

.. selectquestion:: mucp_13_5_sq
   :fromid: mucp_13_5, mucp_13_5_ac_q
   :toggle:

.. selectquestion:: mucp_13_6_sq
   :fromid: mucp_13_6, mucp_13_6_ac_q
   :toggle:

.. selectquestion:: mucp_13_7_sq
   :fromid: mucp_13_7, mucp_13_7_ac_q
   :toggle:

.. selectquestion:: mucp_13_8_sq
   :fromid: mucp_13_8, mucp_13_8_ac_q
   :toggle:

.. selectquestion:: mucp_13_9_sq
   :fromid: mucp_13_9, mucp_13_9_ac_q
   :toggle:

.. selectquestion:: mucp_13_10_sq
   :fromid: mucp_13_10, mucp_13_10_ac_q
   :toggle:
